
#ifndef __PREF_DICTGROUP_H__
#define __PREF_DICTGROUP_H__

#include "defs.h"

void            dicts_show(GtkWidget *w, gpointer data);
void            dicts_save();
void            dicts_load();
GtkWidget*	dicts_info(gboolean create);
BOOK_INFO*      dicts_find_binfo(EB_Book *book);
GtkTreePath*    dicts_find_path(EB_Book *book);

void            my_gtk_tree_store_swap(GtkTreeStore *tree_store, GtkTreeIter *a, GtkTreeIter *b);
void            my_gtk_combo_box_set_active_text(GtkComboBox *combo, const gchar *text);

struct _dicts
{
    gboolean show_info;
    GtkTreeStore *store;
    GtkWidget   *dlg, *view, *path, *search_depth;
} dicts;

#endif /* __PREF_DICTGROUP_H__ */
